# Design for perhaps the simplest way to print a dice face #

**Note:** this design is relatively simple as is moving towards a "good"
design. Use the document on Code Quality to help you see why. Hint: the amount
of code in one place, DRY programming, and the potential reusability and
flexibility and robustness of the design &mdash; or rather the lack of these.

Nevertheless, this design serves a useful purpose as a starting point because it
has the minimum amount of complexities. After having designed a program, get the
core part working in a simple way and then build from there by making code more
flexible and robust and by moving it into new places such as new methods.

## Stages ##

1. input a `String`
2. convert `String` to an `int`
3. print appropriate face according to the value of that `int`

...in that order.

## Essential components ##

Find a way to:

1. print a line in a platform-independent way &mdash; this matters because Java
   programs are supposed to be portable to other operating systems
2. convert a `String` to an `int`
3. read the command-line arguments
4. a way to test equality between what the user wants printing and the
   correct piece of code to do that printing
5. represent each face of the dice

## Additional components ##

1. use `o` to represent a dot and ` ` to represent no dot
2. use `|` for the vertical (left and right) sides of the face
3. use `-` for the horizontal (top and bottom) sides

## Possible variations ##

1. `if` without `else`
2. `switch` instead of `if ... else`
3. read from the keyboard (or a file) instead of using
   the command-line arguments
4. factor out common commands such as printing the top and bottom so that
   these occur fewer times

<STYLE>
* {
  font-size:   1.1rem;
  /*font-size:   1.2rem;*/
  background-color: #2A252A;
  color:            #D5DAD5;
  /*background-color: DarkSlateGray;*/
  /*color:            AntiqueWhite;*/
  /*background-color: black;*/
  /*color: white;*/
  /*background-color: white;*/
  /*color: black;*/
}
body {
  width: 80%;
  font-family: "OpenDyslexic", serif;
  /*font-family: sans-serif;*/
  line-height: 180%;
  /*line-height: 200%;*/
}
pre,
code,
pre code {
  font-family: "OpenDyslexicMono", monospace;
  line-height: 150%;
}
ol,
ol ol,
ol ol ol {
  list-style-type: decimal;
}  
em {
  font-style: normal;
  border-bottom-style: solid;
  border-bottom-width: 1px;
  padding-bottom:      2px;
  /*text-decoration: underline;*/
  text-decoration-skip-ink: auto;
}
h2 {
  border-top:  1px solid #D5DAD5;
  margin-top:  80px;
  padding-top: 20px;
}
</STYLE>